@@ -1,5 +1,6 @@
+# -*- coding: utf-8 -*-
 from django.conf import settings
-from django.core.urlresolvers import is_valid_path, get_script_prefix
+from django.core.urlresolvers import get_script_prefix, is_valid_path
 from django.http import HttpResponseRedirect
 from django.utils.deprecation import MiddlewareMixin
 from django.utils.translation import get_language_from_path
@@ -19,7 +20,7 @@ class LanguagePrefixFallbackMiddleware(MiddlewareMixin):
 
         if not language_prefix:
             return path
-        return "/" + "/".join(path.split("/")[2:])
+        return '/' + '/'.join(path.split('/')[2:])
 
     def process_response(self, request, response):
         language_from_path = get_language_from_path(request.path_info)
@@ -30,12 +31,12 @@ class LanguagePrefixFallbackMiddleware(MiddlewareMixin):
             path_valid = is_valid_path(new_path, urlconf)
 
             if (not path_valid and settings.APPEND_SLASH and not new_path.endswith('/')):
-                path_valid = is_valid_path("%s/" % new_path, urlconf)
+                path_valid = is_valid_path('%s/' % new_path, urlconf)
 
             if path_valid:
                 script_prefix = get_script_prefix()
                 old_path = get_script_prefix() + language_from_path + '/'
-                language_url = "%s://%s%s" % (
+                language_url = '%s://%s%s' % (
                     request.scheme,
                     request.get_host(),
                     # replace the old path which contains language code
